You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by br...@apache.org on 2013/10/22 22:31:45 UTC

[1/9] git commit: Revert use of speculative retries by default for now

Updated Branches:
  refs/heads/cassandra-1.2 12413ad1f -> 59bf44dd9
  refs/heads/cassandra-2.0 b6147c1c7 -> 8a069587d
  refs/heads/trunk 0bff97a2c -> 4d82ac9d2


Revert use of speculative retries by default for now


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/66fe5bda
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/66fe5bda
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/66fe5bda

Branch: refs/heads/trunk
Commit: 66fe5bdaaa1f5e22d33528c3d2313cc23e7621d8
Parents: dfb9765
Author: Sylvain Lebresne <sy...@datastax.com>
Authored: Tue Oct 22 16:08:53 2013 +0200
Committer: Sylvain Lebresne <sy...@datastax.com>
Committed: Tue Oct 22 16:08:53 2013 +0200

----------------------------------------------------------------------
 NEWS.txt                                             | 2 --
 src/java/org/apache/cassandra/config/CFMetaData.java | 2 +-
 2 files changed, 1 insertion(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/66fe5bda/NEWS.txt
----------------------------------------------------------------------
diff --git a/NEWS.txt b/NEWS.txt
index 69ab4fd..e39d5cd 100644
--- a/NEWS.txt
+++ b/NEWS.txt
@@ -19,8 +19,6 @@ using the provided 'sstableupgrade' tool.
 
 New features
 ------------
-    - Speculative retry defaults to 99th percentile
-      (See blog post at http://www.datastax.com/dev/blog/rapid-read-protection-in-cassandra-2-0-2)
     - Configurable metrics reporting
       (see conf/metrics-reporter-config-sample.yaml)
     - Compaction history and stats are now saved to system keyspace

http://git-wip-us.apache.org/repos/asf/cassandra/blob/66fe5bda/src/java/org/apache/cassandra/config/CFMetaData.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/config/CFMetaData.java b/src/java/org/apache/cassandra/config/CFMetaData.java
index d63ee01..479dafc 100644
--- a/src/java/org/apache/cassandra/config/CFMetaData.java
+++ b/src/java/org/apache/cassandra/config/CFMetaData.java
@@ -83,7 +83,7 @@ public final class CFMetaData
     public final static Class<? extends AbstractCompactionStrategy> DEFAULT_COMPACTION_STRATEGY_CLASS = SizeTieredCompactionStrategy.class;
     public final static Caching DEFAULT_CACHING_STRATEGY = Caching.KEYS_ONLY;
     public final static int DEFAULT_DEFAULT_TIME_TO_LIVE = 0;
-    public final static SpeculativeRetry DEFAULT_SPECULATIVE_RETRY = new SpeculativeRetry(SpeculativeRetry.RetryType.PERCENTILE, 0.99);
+    public final static SpeculativeRetry DEFAULT_SPECULATIVE_RETRY = new SpeculativeRetry(SpeculativeRetry.RetryType.NONE, 0);
     public final static int DEFAULT_INDEX_INTERVAL = 128;
     public final static boolean DEFAULT_POPULATE_IO_CACHE_ON_FLUSH = false;
 


[4/9] git commit: Fix harmless NPE in MM/HHOM Patch by brandonwilliams, reviewed by Tyler Hobbs for CASSANDRA-5185

Posted by br...@apache.org.
Fix harmless NPE in MM/HHOM
Patch by brandonwilliams, reviewed by Tyler Hobbs for CASSANDRA-5185


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/59bf44dd
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/59bf44dd
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/59bf44dd

Branch: refs/heads/cassandra-1.2
Commit: 59bf44dd94939cea513a74250f6002357d1f9f2c
Parents: 12413ad
Author: Brandon Williams <br...@apache.org>
Authored: Tue Oct 22 15:28:47 2013 -0500
Committer: Brandon Williams <br...@apache.org>
Committed: Tue Oct 22 15:28:47 2013 -0500

----------------------------------------------------------------------
 src/java/org/apache/cassandra/db/HintedHandOffManager.java  | 8 ++++++--
 src/java/org/apache/cassandra/service/MigrationManager.java | 5 ++++-
 2 files changed, 10 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/59bf44dd/src/java/org/apache/cassandra/db/HintedHandOffManager.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/db/HintedHandOffManager.java b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
index c333359..ede49e4 100644
--- a/src/java/org/apache/cassandra/db/HintedHandOffManager.java
+++ b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
@@ -209,7 +209,7 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
         Gossiper gossiper = Gossiper.instance;
         int waited = 0;
         // first, wait for schema to be gossiped.
-        while (gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
+        while (gossiper.getEndpointStateForEndpoint(endpoint) != null && gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
         {
             try
             {
@@ -223,12 +223,14 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
             if (waited > 2 * StorageService.RING_DELAY)
                 throw new TimeoutException("Didin't receive gossiped schema from " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
         }
+        if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+            throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
         waited = 0;
         // then wait for the correct schema version.
         // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system table.
         // here we check the one in gossip instead; this serves as a canary to warn us if we introduce a bug that
         // causes the two to diverge (see CASSANDRA-2946)
-        while (!gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
+        while (gossiper.getEndpointStateForEndpoint(endpoint) != null && !gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
                 gossiper.getEndpointStateForEndpoint(FBUtilities.getBroadcastAddress()).getApplicationState(ApplicationState.SCHEMA).value))
         {
             try
@@ -243,6 +245,8 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
             if (waited > 2 * StorageService.RING_DELAY)
                 throw new TimeoutException("Could not reach schema agreement with " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
         }
+        if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+            throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
         logger.debug("schema for {} matches local schema", endpoint);
         return waited;
     }

http://git-wip-us.apache.org/repos/asf/cassandra/blob/59bf44dd/src/java/org/apache/cassandra/service/MigrationManager.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/service/MigrationManager.java b/src/java/org/apache/cassandra/service/MigrationManager.java
index e901b61..3ede35e 100644
--- a/src/java/org/apache/cassandra/service/MigrationManager.java
+++ b/src/java/org/apache/cassandra/service/MigrationManager.java
@@ -127,7 +127,10 @@ public class MigrationManager implements IEndpointStateChangeSubscriber
                 public void run()
                 {
                     // grab the latest version of the schema since it may have changed again since the initial scheduling
-                    VersionedValue value = Gossiper.instance.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA);
+                    EndpointState epState = Gossiper.instance.getEndpointStateForEndpoint(endpoint);
+                    if (epState == null)
+                        return;
+                    VersionedValue value = epState.getApplicationState(ApplicationState.SCHEMA);
                     UUID currentVersion = UUID.fromString(value.value);
                     if (Schema.instance.getVersion().equals(currentVersion))
                         return;


[3/9] git commit: License and versions for 2.0.2 release

Posted by br...@apache.org.
License and versions for 2.0.2 release


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/b6147c1c
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/b6147c1c
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/b6147c1c

Branch: refs/heads/trunk
Commit: b6147c1c7bfca817429f1e13d4dd9096bee5e626
Parents: 7159ec1
Author: Sylvain Lebresne <sy...@datastax.com>
Authored: Tue Oct 22 18:01:51 2013 +0200
Committer: Sylvain Lebresne <sy...@datastax.com>
Committed: Tue Oct 22 18:01:51 2013 +0200

----------------------------------------------------------------------
 .rat-excludes                                   |  1 +
 build.xml                                       |  2 +-
 debian/changelog                                |  6 ++++++
 examples/triggers/build.xml                     | 19 +++++++++++++++++++
 examples/triggers/conf/InvertedIndex.properties | 19 ++++++++++++++++++-
 .../filter/TombstoneOverwhelmingException.java  | 18 ++++++++++++++++++
 .../cassandra/metrics/RestorableMeter.java      | 20 +++++++++++++++++++-
 .../apache/cassandra/net/WriteCallbackInfo.java | 18 ++++++++++++++++++
 .../cassandra/pig/CqlTableDataTypeTest.java     | 18 ++++++++++++++++++
 .../pig/ThriftColumnFamilyDataTypeTest.java     | 18 ++++++++++++++++++
 10 files changed, 136 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/.rat-excludes
----------------------------------------------------------------------
diff --git a/.rat-excludes b/.rat-excludes
index 8d2ead8..78473b9 100644
--- a/.rat-excludes
+++ b/.rat-excludes
@@ -15,6 +15,7 @@ lib/licenses/*.txt
 .settings/**
 **/cassandra.yaml
 **/cassandra-topology.yaml
+**/metrics-reporter-config-sample.yaml
 **/*.db
 .externalToolBuilders/**
 test/data/serialization/*/*

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/build.xml
----------------------------------------------------------------------
diff --git a/build.xml b/build.xml
index 2703edf..09a0213 100644
--- a/build.xml
+++ b/build.xml
@@ -25,7 +25,7 @@
     <property name="debuglevel" value="source,lines,vars"/>
 
     <!-- default version and SCM information -->
-    <property name="base.version" value="2.0.1"/>
+    <property name="base.version" value="2.0.2"/>
     <property name="scm.connection" value="scm:git://git.apache.org/cassandra.git"/>
     <property name="scm.developerConnection" value="scm:git://git.apache.org/cassandra.git"/>
     <property name="scm.url" value="http://git-wip-us.apache.org/repos/asf?p=cassandra.git;a=tree"/>

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/debian/changelog
----------------------------------------------------------------------
diff --git a/debian/changelog b/debian/changelog
index 61a91d7..4d99120 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,9 @@
+cassandra (2.0.2) unstable; urgency=low
+
+  * New release
+
+ -- Sylvain Lebresne <sl...@apache.org>  Tue, 22 Oct 2013 17:44:30 +0200
+
 cassandra (2.0.1) unstable; urgency=low
 
   * New release

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/examples/triggers/build.xml
----------------------------------------------------------------------
diff --git a/examples/triggers/build.xml b/examples/triggers/build.xml
index 55fccce..293b08d 100644
--- a/examples/triggers/build.xml
+++ b/examples/triggers/build.xml
@@ -1,4 +1,23 @@
 <?xml version="1.0" encoding="UTF-8"?>
+<!--
+ ~ Licensed to the Apache Software Foundation (ASF) under one
+ ~ or more contributor license agreements.  See the NOTICE file
+ ~ distributed with this work for additional information
+ ~ regarding copyright ownership.  The ASF licenses this file
+ ~ to you under the Apache License, Version 2.0 (the
+ ~ "License"); you may not use this file except in compliance
+ ~ with the License.  You may obtain a copy of the License at
+ ~
+ ~   http://www.apache.org/licenses/LICENSE-2.0
+ ~
+ ~ Unless required by applicable law or agreed to in writing,
+ ~ software distributed under the License is distributed on an
+ ~ "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ ~ KIND, either express or implied.  See the License for the
+ ~ specific language governing permissions and limitations
+ ~ under the License.
+-->
+
 <project default="jar" name="trigger-example">
 	<property name="cassandra.dir" value="../.." />
 	<property name="cassandra.dir.lib" value="${cassandra.dir}/lib" />

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/examples/triggers/conf/InvertedIndex.properties
----------------------------------------------------------------------
diff --git a/examples/triggers/conf/InvertedIndex.properties b/examples/triggers/conf/InvertedIndex.properties
index 6db6d61..3ec2bb0 100644
--- a/examples/triggers/conf/InvertedIndex.properties
+++ b/examples/triggers/conf/InvertedIndex.properties
@@ -1,2 +1,19 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 keyspace=Keyspace1
-columnfamily=InvertedIndex
\ No newline at end of file
+columnfamily=InvertedIndex

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/src/java/org/apache/cassandra/db/filter/TombstoneOverwhelmingException.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/db/filter/TombstoneOverwhelmingException.java b/src/java/org/apache/cassandra/db/filter/TombstoneOverwhelmingException.java
index 5975463..6a6b0f6 100644
--- a/src/java/org/apache/cassandra/db/filter/TombstoneOverwhelmingException.java
+++ b/src/java/org/apache/cassandra/db/filter/TombstoneOverwhelmingException.java
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.cassandra.db.filter;
 
 public class TombstoneOverwhelmingException extends RuntimeException

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/src/java/org/apache/cassandra/metrics/RestorableMeter.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/metrics/RestorableMeter.java b/src/java/org/apache/cassandra/metrics/RestorableMeter.java
index 7da2ff9..4df4665 100644
--- a/src/java/org/apache/cassandra/metrics/RestorableMeter.java
+++ b/src/java/org/apache/cassandra/metrics/RestorableMeter.java
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.cassandra.metrics;
 
 import com.yammer.metrics.core.Clock;
@@ -182,4 +200,4 @@ public class RestorableMeter
             return rate * NANOS_PER_SECOND;
         }
     }
-}
\ No newline at end of file
+}

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/src/java/org/apache/cassandra/net/WriteCallbackInfo.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/net/WriteCallbackInfo.java b/src/java/org/apache/cassandra/net/WriteCallbackInfo.java
index abded75..38e4b5a 100644
--- a/src/java/org/apache/cassandra/net/WriteCallbackInfo.java
+++ b/src/java/org/apache/cassandra/net/WriteCallbackInfo.java
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.cassandra.net;
 
 import java.net.InetAddress;

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/test/unit/org/apache/cassandra/pig/CqlTableDataTypeTest.java
----------------------------------------------------------------------
diff --git a/test/unit/org/apache/cassandra/pig/CqlTableDataTypeTest.java b/test/unit/org/apache/cassandra/pig/CqlTableDataTypeTest.java
index a0f1f47..352b2e2 100644
--- a/test/unit/org/apache/cassandra/pig/CqlTableDataTypeTest.java
+++ b/test/unit/org/apache/cassandra/pig/CqlTableDataTypeTest.java
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.cassandra.pig;
 
 import java.io.IOException;

http://git-wip-us.apache.org/repos/asf/cassandra/blob/b6147c1c/test/unit/org/apache/cassandra/pig/ThriftColumnFamilyDataTypeTest.java
----------------------------------------------------------------------
diff --git a/test/unit/org/apache/cassandra/pig/ThriftColumnFamilyDataTypeTest.java b/test/unit/org/apache/cassandra/pig/ThriftColumnFamilyDataTypeTest.java
index 2f97549..cc54620 100644
--- a/test/unit/org/apache/cassandra/pig/ThriftColumnFamilyDataTypeTest.java
+++ b/test/unit/org/apache/cassandra/pig/ThriftColumnFamilyDataTypeTest.java
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.cassandra.pig;
 
 import java.io.IOException;


[2/9] git commit: Fix SSTableLoader

Posted by br...@apache.org.
Fix SSTableLoader

patch by thobbs; reviewed by slebresne for CASSANDRA-6205


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/7159ec10
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/7159ec10
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/7159ec10

Branch: refs/heads/trunk
Commit: 7159ec10046fd4dce58ca9406ef096fdb965700d
Parents: 66fe5bd
Author: Sylvain Lebresne <sy...@datastax.com>
Authored: Tue Oct 22 17:42:50 2013 +0200
Committer: Sylvain Lebresne <sy...@datastax.com>
Committed: Tue Oct 22 17:42:50 2013 +0200

----------------------------------------------------------------------
 CHANGES.txt                                               |  1 +
 .../org/apache/cassandra/io/sstable/SSTableReader.java    | 10 ++++------
 2 files changed, 5 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/7159ec10/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index e89ca41..ac4c010 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -26,6 +26,7 @@
  * CQL3: support pre-epoch longs for TimestampType (CASSANDRA-6212)
  * Add reloadtriggers command to nodetool (CASSANDRA-4949)
  * cqlsh: ignore empty 'value alias' in DESCRIBE (CASSANDRA-6139)
+ * Fix sstable loader (CASSANDRA-6205)
 Merged from 1.2:
  * (Hadoop) Require CFRR batchSize to be at least 2 (CASSANDRA-6114)
  * Add a warning for small LCS sstable size (CASSANDRA-6191)

http://git-wip-us.apache.org/repos/asf/cassandra/blob/7159ec10/src/java/org/apache/cassandra/io/sstable/SSTableReader.java
----------------------------------------------------------------------
diff --cc src/java/org/apache/cassandra/db/HintedHandOffManager.java
index 67a5c68,ede49e4..f1e751f
--- a/src/java/org/apache/cassandra/db/HintedHandOffManager.java
+++ b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
@@@ -249,22 -209,38 +249,24 @@@ public class HintedHandOffManager imple
          Gossiper gossiper = Gossiper.instance;
          int waited = 0;
          // first, wait for schema to be gossiped.
-         while (gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
+         while (gossiper.getEndpointStateForEndpoint(endpoint) != null && gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
          {
 -            try
 -            {
 -                Thread.sleep(1000);
 -            }
 -            catch (InterruptedException e)
 -            {
 -                throw new AssertionError(e);
 -            }
 +            Uninterruptibles.sleepUninterruptibly(1, TimeUnit.SECONDS);
              waited += 1000;
              if (waited > 2 * StorageService.RING_DELAY)
                  throw new TimeoutException("Didin't receive gossiped schema from " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
          }
+         if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+             throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
          waited = 0;
          // then wait for the correct schema version.
 -        // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system table.
 +        // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system keyspace.
          // here we check the one in gossip instead; this serves as a canary to warn us if we introduce a bug that
          // causes the two to diverge (see CASSANDRA-2946)
-         while (!gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
+         while (gossiper.getEndpointStateForEndpoint(endpoint) != null && !gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
                  gossiper.getEndpointStateForEndpoint(FBUtilities.getBroadcastAddress()).getApplicationState(ApplicationState.SCHEMA).value))
          {
 -            try
 -            {
 -                Thread.sleep(1000);
 -            }
 -            catch (InterruptedException e)
 -            {
 -                throw new AssertionError(e);
 -            }
 +            Uninterruptibles.sleepUninterruptibly(1, TimeUnit.SECONDS);
              waited += 1000;
              if (waited > 2 * StorageService.RING_DELAY)
                  throw new TimeoutException("Could not reach schema agreement with " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");

http://git-wip-us.apache.org/repos/asf/cassandra/blob/8a069587/src/java/org/apache/cassandra/service/MigrationManager.java
----------------------------------------------------------------------


[7/9] git commit: Merge branch 'cassandra-1.2' into cassandra-2.0

Posted by br...@apache.org.
Merge branch 'cassandra-1.2' into cassandra-2.0


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/8a069587
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/8a069587
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/8a069587

Branch: refs/heads/trunk
Commit: 8a069587d5f67d64d99e9d391e5f6a733616ab97
Parents: b6147c1 59bf44d
Author: Brandon Williams <br...@apache.org>
Authored: Tue Oct 22 15:29:24 2013 -0500
Committer: Brandon Williams <br...@apache.org>
Committed: Tue Oct 22 15:29:24 2013 -0500

----------------------------------------------------------------------
 src/java/org/apache/cassandra/db/HintedHandOffManager.java  | 8 ++++++--
 src/java/org/apache/cassandra/service/MigrationManager.java | 5 ++++-
 2 files changed, 10 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/8a069587/src/java/org/apache/cassandra/db/HintedHandOffManager.java
----------------------------------------------------------------------
diff --cc src/java/org/apache/cassandra/db/HintedHandOffManager.java
index 67a5c68,ede49e4..f1e751f
--- a/src/java/org/apache/cassandra/db/HintedHandOffManager.java
+++ b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
@@@ -249,22 -209,38 +249,24 @@@ public class HintedHandOffManager imple
          Gossiper gossiper = Gossiper.instance;
          int waited = 0;
          // first, wait for schema to be gossiped.
-         while (gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
+         while (gossiper.getEndpointStateForEndpoint(endpoint) != null && gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
          {
 -            try
 -            {
 -                Thread.sleep(1000);
 -            }
 -            catch (InterruptedException e)
 -            {
 -                throw new AssertionError(e);
 -            }
 +            Uninterruptibles.sleepUninterruptibly(1, TimeUnit.SECONDS);
              waited += 1000;
              if (waited > 2 * StorageService.RING_DELAY)
                  throw new TimeoutException("Didin't receive gossiped schema from " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
          }
+         if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+             throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
          waited = 0;
          // then wait for the correct schema version.
 -        // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system table.
 +        // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system keyspace.
          // here we check the one in gossip instead; this serves as a canary to warn us if we introduce a bug that
          // causes the two to diverge (see CASSANDRA-2946)
-         while (!gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
+         while (gossiper.getEndpointStateForEndpoint(endpoint) != null && !gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
                  gossiper.getEndpointStateForEndpoint(FBUtilities.getBroadcastAddress()).getApplicationState(ApplicationState.SCHEMA).value))
          {
 -            try
 -            {
 -                Thread.sleep(1000);
 -            }
 -            catch (InterruptedException e)
 -            {
 -                throw new AssertionError(e);
 -            }
 +            Uninterruptibles.sleepUninterruptibly(1, TimeUnit.SECONDS);
              waited += 1000;
              if (waited > 2 * StorageService.RING_DELAY)
                  throw new TimeoutException("Could not reach schema agreement with " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");

http://git-wip-us.apache.org/repos/asf/cassandra/blob/8a069587/src/java/org/apache/cassandra/service/MigrationManager.java
----------------------------------------------------------------------


[9/9] git commit: Merge branch 'cassandra-2.0' into trunk

Posted by br...@apache.org.
Merge branch 'cassandra-2.0' into trunk

Conflicts:
	build.xml


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/4d82ac9d
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/4d82ac9d
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/4d82ac9d

Branch: refs/heads/trunk
Commit: 4d82ac9d29a2f329fa7236704b06464430d53f76
Parents: 0bff97a 8a06958
Author: Brandon Williams <br...@apache.org>
Authored: Tue Oct 22 15:30:07 2013 -0500
Committer: Brandon Williams <br...@apache.org>
Committed: Tue Oct 22 15:30:07 2013 -0500

----------------------------------------------------------------------
 .rat-excludes                                   |  1 +
 CHANGES.txt                                     |  1 +
 NEWS.txt                                        |  2 --
 debian/changelog                                |  6 ++++++
 examples/triggers/build.xml                     | 19 +++++++++++++++++++
 examples/triggers/conf/InvertedIndex.properties | 19 ++++++++++++++++++-
 .../org/apache/cassandra/config/CFMetaData.java |  2 +-
 .../cassandra/db/HintedHandOffManager.java      |  8 ++++++--
 .../filter/TombstoneOverwhelmingException.java  | 18 ++++++++++++++++++
 .../cassandra/io/sstable/SSTableReader.java     | 10 ++++------
 .../cassandra/metrics/RestorableMeter.java      | 20 +++++++++++++++++++-
 .../apache/cassandra/net/WriteCallbackInfo.java | 18 ++++++++++++++++++
 .../cassandra/service/MigrationManager.java     |  5 ++++-
 .../cassandra/pig/CqlTableDataTypeTest.java     | 18 ++++++++++++++++++
 .../pig/ThriftColumnFamilyDataTypeTest.java     | 18 ++++++++++++++++++
 15 files changed, 151 insertions(+), 14 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/4d82ac9d/CHANGES.txt
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/cassandra/blob/4d82ac9d/NEWS.txt
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/cassandra/blob/4d82ac9d/src/java/org/apache/cassandra/config/CFMetaData.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/cassandra/blob/4d82ac9d/src/java/org/apache/cassandra/db/HintedHandOffManager.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/cassandra/blob/4d82ac9d/src/java/org/apache/cassandra/io/sstable/SSTableReader.java
----------------------------------------------------------------------

http://git-wip-us.apache.org/repos/asf/cassandra/blob/4d82ac9d/src/java/org/apache/cassandra/service/MigrationManager.java
----------------------------------------------------------------------


[5/9] git commit: Fix harmless NPE in MM/HHOM Patch by brandonwilliams, reviewed by Tyler Hobbs for CASSANDRA-5185

Posted by br...@apache.org.
Fix harmless NPE in MM/HHOM
Patch by brandonwilliams, reviewed by Tyler Hobbs for CASSANDRA-5185


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/59bf44dd
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/59bf44dd
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/59bf44dd

Branch: refs/heads/trunk
Commit: 59bf44dd94939cea513a74250f6002357d1f9f2c
Parents: 12413ad
Author: Brandon Williams <br...@apache.org>
Authored: Tue Oct 22 15:28:47 2013 -0500
Committer: Brandon Williams <br...@apache.org>
Committed: Tue Oct 22 15:28:47 2013 -0500

----------------------------------------------------------------------
 src/java/org/apache/cassandra/db/HintedHandOffManager.java  | 8 ++++++--
 src/java/org/apache/cassandra/service/MigrationManager.java | 5 ++++-
 2 files changed, 10 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/59bf44dd/src/java/org/apache/cassandra/db/HintedHandOffManager.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/db/HintedHandOffManager.java b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
index c333359..ede49e4 100644
--- a/src/java/org/apache/cassandra/db/HintedHandOffManager.java
+++ b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
@@ -209,7 +209,7 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
         Gossiper gossiper = Gossiper.instance;
         int waited = 0;
         // first, wait for schema to be gossiped.
-        while (gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
+        while (gossiper.getEndpointStateForEndpoint(endpoint) != null && gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
         {
             try
             {
@@ -223,12 +223,14 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
             if (waited > 2 * StorageService.RING_DELAY)
                 throw new TimeoutException("Didin't receive gossiped schema from " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
         }
+        if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+            throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
         waited = 0;
         // then wait for the correct schema version.
         // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system table.
         // here we check the one in gossip instead; this serves as a canary to warn us if we introduce a bug that
         // causes the two to diverge (see CASSANDRA-2946)
-        while (!gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
+        while (gossiper.getEndpointStateForEndpoint(endpoint) != null && !gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
                 gossiper.getEndpointStateForEndpoint(FBUtilities.getBroadcastAddress()).getApplicationState(ApplicationState.SCHEMA).value))
         {
             try
@@ -243,6 +245,8 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
             if (waited > 2 * StorageService.RING_DELAY)
                 throw new TimeoutException("Could not reach schema agreement with " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
         }
+        if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+            throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
         logger.debug("schema for {} matches local schema", endpoint);
         return waited;
     }

http://git-wip-us.apache.org/repos/asf/cassandra/blob/59bf44dd/src/java/org/apache/cassandra/service/MigrationManager.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/service/MigrationManager.java b/src/java/org/apache/cassandra/service/MigrationManager.java
index e901b61..3ede35e 100644
--- a/src/java/org/apache/cassandra/service/MigrationManager.java
+++ b/src/java/org/apache/cassandra/service/MigrationManager.java
@@ -127,7 +127,10 @@ public class MigrationManager implements IEndpointStateChangeSubscriber
                 public void run()
                 {
                     // grab the latest version of the schema since it may have changed again since the initial scheduling
-                    VersionedValue value = Gossiper.instance.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA);
+                    EndpointState epState = Gossiper.instance.getEndpointStateForEndpoint(endpoint);
+                    if (epState == null)
+                        return;
+                    VersionedValue value = epState.getApplicationState(ApplicationState.SCHEMA);
                     UUID currentVersion = UUID.fromString(value.value);
                     if (Schema.instance.getVersion().equals(currentVersion))
                         return;


[6/9] git commit: Fix harmless NPE in MM/HHOM Patch by brandonwilliams, reviewed by Tyler Hobbs for CASSANDRA-5185

Posted by br...@apache.org.
Fix harmless NPE in MM/HHOM
Patch by brandonwilliams, reviewed by Tyler Hobbs for CASSANDRA-5185


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/59bf44dd
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/59bf44dd
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/59bf44dd

Branch: refs/heads/cassandra-2.0
Commit: 59bf44dd94939cea513a74250f6002357d1f9f2c
Parents: 12413ad
Author: Brandon Williams <br...@apache.org>
Authored: Tue Oct 22 15:28:47 2013 -0500
Committer: Brandon Williams <br...@apache.org>
Committed: Tue Oct 22 15:28:47 2013 -0500

----------------------------------------------------------------------
 src/java/org/apache/cassandra/db/HintedHandOffManager.java  | 8 ++++++--
 src/java/org/apache/cassandra/service/MigrationManager.java | 5 ++++-
 2 files changed, 10 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/59bf44dd/src/java/org/apache/cassandra/db/HintedHandOffManager.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/db/HintedHandOffManager.java b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
index c333359..ede49e4 100644
--- a/src/java/org/apache/cassandra/db/HintedHandOffManager.java
+++ b/src/java/org/apache/cassandra/db/HintedHandOffManager.java
@@ -209,7 +209,7 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
         Gossiper gossiper = Gossiper.instance;
         int waited = 0;
         // first, wait for schema to be gossiped.
-        while (gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
+        while (gossiper.getEndpointStateForEndpoint(endpoint) != null && gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA) == null)
         {
             try
             {
@@ -223,12 +223,14 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
             if (waited > 2 * StorageService.RING_DELAY)
                 throw new TimeoutException("Didin't receive gossiped schema from " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
         }
+        if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+            throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
         waited = 0;
         // then wait for the correct schema version.
         // usually we use DD.getDefsVersion, which checks the local schema uuid as stored in the system table.
         // here we check the one in gossip instead; this serves as a canary to warn us if we introduce a bug that
         // causes the two to diverge (see CASSANDRA-2946)
-        while (!gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
+        while (gossiper.getEndpointStateForEndpoint(endpoint) != null && !gossiper.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA).value.equals(
                 gossiper.getEndpointStateForEndpoint(FBUtilities.getBroadcastAddress()).getApplicationState(ApplicationState.SCHEMA).value))
         {
             try
@@ -243,6 +245,8 @@ public class HintedHandOffManager implements HintedHandOffManagerMBean
             if (waited > 2 * StorageService.RING_DELAY)
                 throw new TimeoutException("Could not reach schema agreement with " + endpoint + " in " + 2 * StorageService.RING_DELAY + "ms");
         }
+        if (gossiper.getEndpointStateForEndpoint(endpoint) == null)
+            throw new TimeoutException("Node " + endpoint + " vanished while waiting for agreement");
         logger.debug("schema for {} matches local schema", endpoint);
         return waited;
     }

http://git-wip-us.apache.org/repos/asf/cassandra/blob/59bf44dd/src/java/org/apache/cassandra/service/MigrationManager.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/service/MigrationManager.java b/src/java/org/apache/cassandra/service/MigrationManager.java
index e901b61..3ede35e 100644
--- a/src/java/org/apache/cassandra/service/MigrationManager.java
+++ b/src/java/org/apache/cassandra/service/MigrationManager.java
@@ -127,7 +127,10 @@ public class MigrationManager implements IEndpointStateChangeSubscriber
                 public void run()
                 {
                     // grab the latest version of the schema since it may have changed again since the initial scheduling
-                    VersionedValue value = Gossiper.instance.getEndpointStateForEndpoint(endpoint).getApplicationState(ApplicationState.SCHEMA);
+                    EndpointState epState = Gossiper.instance.getEndpointStateForEndpoint(endpoint);
+                    if (epState == null)
+                        return;
+                    VersionedValue value = epState.getApplicationState(ApplicationState.SCHEMA);
                     UUID currentVersion = UUID.fromString(value.value);
                     if (Schema.instance.getVersion().equals(currentVersion))
                         return;
diff --git a/src/java/org/apache/cassandra/io/sstable/SSTableReader.java b/src/java/org/apache/cassandra/io/sstable/SSTableReader.java
index cb0873d..9837f4c 100644
--- a/src/java/org/apache/cassandra/io/sstable/SSTableReader.java
+++ b/src/java/org/apache/cassandra/io/sstable/SSTableReader.java
@@ -36,10 +36,7 @@ import org.slf4j.LoggerFactory;
 import org.apache.cassandra.cache.InstrumentingCache;
 import org.apache.cassandra.cache.KeyCacheKey;
 import org.apache.cassandra.concurrent.DebuggableThreadPoolExecutor;
-import org.apache.cassandra.config.CFMetaData;
-import org.apache.cassandra.config.ColumnDefinition;
-import org.apache.cassandra.config.DatabaseDescriptor;
-import org.apache.cassandra.config.Schema;
+import org.apache.cassandra.config.*;
 import org.apache.cassandra.db.*;
 import org.apache.cassandra.db.columniterator.OnDiskAtomIterator;
 import org.apache.cassandra.db.commitlog.ReplayPosition;
@@ -327,8 +324,9 @@ public class SSTableReader extends SSTable implements Closeable
 
         deletingTask = new SSTableDeletingTask(this);
 
-        // Don't track read rates for tables in the system keyspace
-        if (Keyspace.SYSTEM_KS.equals(desc.ksname))
+        // Don't track read rates for tables in the system keyspace and don't bother trying to load or persist
+        // the read meter when in client mode
+        if (Keyspace.SYSTEM_KS.equals(desc.ksname) || Config.isClientMode())
         {
             readMeter = null;
             return;


[8/9] git commit: Merge branch 'cassandra-1.2' into cassandra-2.0

Posted by br...@apache.org.
Merge branch 'cassandra-1.2' into cassandra-2.0


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/8a069587
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/8a069587
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/8a069587

Branch: refs/heads/cassandra-2.0
Commit: 8a069587d5f67d64d99e9d391e5f6a733616ab97
Parents: b6147c1 59bf44d
Author: Brandon Williams <br...@apache.org>
Authored: Tue Oct 22 15:29:24 2013 -0500
Committer: Brandon Williams <br...@apache.org>
Committed: Tue Oct 22 15:29:24 2013 -0500

----------------------------------------------------------------------
 src/java/org/apache/cassandra/db/HintedHandOffManager.java  | 8 ++++++--
 src/java/org/apache/cassandra/service/MigrationManager.java | 5 ++++-
 2 files changed, 10 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/8a069587/src/java/org/apache/cassandra/db/HintedHandOffManager.java
----------------------------------------------------------------------